@@ -26,7 +26,7 @@ import cmd, re, os, sys, optparse, subprocess, tempfile, pyparsing, doctest
 import unittest, string, datetime, urllib, glob
 from code import InteractiveConsole, InteractiveInterpreter, softspace
 from optparse import make_option
-__version__ = '0.5.4'
+__version__ = '0.5.5'
 
 class OptionParser(optparse.OptionParser):
     def exit(self, status=0, msg=None):
@@ -335,6 +335,7 @@ class Cmd(cmd.Cmd):
     commentGrammars = pyparsing.Or([pyparsing.pythonStyleComment, pyparsing.cStyleComment])
     commentGrammars.addParseAction(lambda x: '')
     commentInProgress  = pyparsing.Literal('/*') + pyparsing.SkipTo(pyparsing.stringEnd)
+    commentInProgress = pyparsing.NoMatch()
     terminators = [';']
     blankLinesAllowed = False
     multilineCommands = []
@@ -523,9 +524,9 @@ class Cmd(cmd.Cmd):
         self.multilineParser.ignore(self.commentInProgress)
         self.singleLineParser = ((oneLineCommand + pyparsing.SkipTo(terminatorParser ^ stringEnd ^ pipe ^ outputParser).setParseAction(lambda x:x[0].strip())('args'))('statement') +
                                  pyparsing.Optional(terminatorParser) + afterElements)
-        #self.multilineParser = self.multilineParser.setResultsName('multilineParser')
-        #self.singleLineParser = self.singleLineParser.setResultsName('singleLineParser')
-        #self.blankLineTerminationParser = self.blankLineTerminationParser.setResultsName('blankLineTerminatorParser')
+        self.multilineParser = self.multilineParser.setResultsName('multilineParser')
+        self.singleLineParser = self.singleLineParser.setResultsName('singleLineParser')
+        self.blankLineTerminationParser = self.blankLineTerminationParser.setResultsName('blankLineTerminatorParser')
         self.parser = self.prefixParser + (
             stringEnd |
             self.multilineParser |
